package PipSqueek::Config;
use base 'Class::Accessor::Fast';

use File::Spec::Functions;


sub new
{
	my $proto = shift;
	my $class = ref($proto) || $proto;
	my $self  = bless( {}, $class );

	my ($root,$path) = @_;

	unless( $root && $path )
	{
		die "Must give configuration object a root and local path " .
		    "to search for appropriate configuration data";
	}


	# these are a couple of internal (non-configurable) parameters
	$self->mk_accessors( 'pipsqueek_version', 'current_nickname',
			     '_root', '_path' );

	$self->_root( $root );
	$self->_path( $path );


	# the pipsqueek version string
	$self->pipsqueek_version("PipSqueek v5.0.0: http://pipsqueek.net/");

	return $self;
}


# This method will take a filename or plugin object/name and reads data in from
# the appropriate configuration file
sub load_config
{
	my ($self,$thing) = @_;
	my $filename = $thing;

	if( ref($thing) || $thing =~ m/^PipSqueek::Plugin::/ )
	{
		$filename = ref($thing) || $thing;
		$filename =~ s/^PipSqueek::Plugin:://;
		$filename = "etc/plugins/$filename.conf";
	}

	# determine what configuration file to use
	my $file = catfile( $self->_path(), $filename );

	if( -e $file ) {
		$filename = $file;
	} else {
		$file = catfile( $self->_root(), $filename );

		if( -e $file ) {
			$filename = $file;
		} else {
			return 0;
		}
	}


#print "* Load Config: $filename\n";

	open( my $fh, '<', $filename )
		or die "Unable to read '$filename': $!\n";
	my @lines = grep {!/^\s*#/} <$fh>;
	chomp(@lines);
	close( $fh );

	foreach my $line ( @lines )
	{
		next unless $line =~ /[^\s]/;

		# parse out a simple key=value
		my ($k,$v) = $line =~ /^\s*(.+?)\s*[=:\t]\s*(.+?)\s*;?\s*$/;

		# trim whitespace on key
		$k =~ s/^\s*|\s*$//g;

		if( $v =~ /^\s*["'](.*?)['"]\s*;?$/ )
		# grab everything in between the outermost quotes
		{
			$v = $1;
		} 
		else
		# doesn't have quoted data
		{
			# trim whitespace on value
			$v =~ s/^\s*|\s*$//g;
		}

		$self->mk_accessors( $k );
		$self->$k( $v );
	}

	return 1;
}


1;


__END__
