package PipSqueek::Plugin::LinkGrabber;
use base qw(PipSqueek::Plugin);

use URI::Find::Schemeless;

sub plugin_initialize
{
	my $self = shift;

	$self->plugin_handlers([
		'irc_public',
		'multi_urls',
	]);

	my $schema = [
		[ 'id',		'INTEGER PRIMARY KEY' ],
		[ 'userid',	'INT NOT NULL' ],
		[ 'time',	'INT NOT NULL DEFAULT 0' ],
		[ 'url',	'VARCHAR NOT NULL' ],
	];

	$self->dbi()->install_schema( 'linkgrabber', $schema );
}


sub irc_public
{
	my ($self,$message) = @_;

	my $user = $self->search_user( $message );
	my $text = $message->message();

	my $finder = URI::Find::Schemeless->new( 
		sub { $self->add_url( $user, @_ ); } 
	);

	my $count = $finder->find( \$text );

	return;
}


sub add_url
{
	my ($self,$user,$uri,$orig_uri) = @_;
	my $url = $uri->as_string();

	$self->dbi()->create_record( 'linkgrabber', 
		{
		'url' => $url,
		'time' => time(),
		'userid' => $user->{'id'},
		} 
	);
}


sub multi_urls
{
	my ($self,$message) = @_;
	my ($amount,$name) = $message->command_input() =~ 
		m/^(?:(\d+))?\s*(?:(.*?))?$/;

	my $config = $self->config();
	my $default = $config->linkgrabber_default();
	my $maximum = $config->linkgrabber_maximum();

	$amount ||= $default;
	$amount = $maximum if $amount > $maximum;

	my @links = ();

	if( $name )
	{
		my $user = $self->search_user($name);

		unless( $user )
		{
			$self->respond($message, "That user does not exist.");
			return;
		}

		my $sql = 'SELECT url FROM linkgrabber WHERE userid=? ' .
			  "ORDER BY time DESC LIMIT $amount";
		my $sth = $self->dbi()->dbh()->prepare($sql);
		   $sth->execute( $user->{'id'} );

		@links = map { $_->[0] } @{$sth->fetchall_arrayref()};
	}
	else
	{
		my $sql = 'SELECT url FROM linkgrabber ' .
			  "ORDER BY time DESC LIMIT $amount";
		my $sth = $self->dbi()->dbh()->prepare($sql);
		   $sth->execute();

		@links = map { $_->[0] } @{$sth->fetchall_arrayref()};
	}

	if( @links )
	{
		local $" = ' - ';
		my $s = $amount == 1 ? "" : 's';

		$self->respond( $message, "Last $amount URL$s" . 
					  ($name ? " from user $name" : '') .
					  ": @links" );
		return;
	}
	else
	{
		$self->respond( $message, "No urls found" .
					  ($name ? " from user $name" : '') );
		return;
	}
}


1;


__END__
